# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/radar/conti_radar/proto/conti_radar_conf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.canbus.proto import can_card_parameter_pb2 as modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/radar/conti_radar/proto/conti_radar_conf.proto',
  package='apollo.drivers.conti_radar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>modules/drivers/radar/conti_radar/proto/conti_radar_conf.proto\x12\x1a\x61pollo.drivers.conti_radar\x1a\x35modules/drivers/canbus/proto/can_card_parameter.proto\"\xb6\x01\n\x07\x43\x61nConf\x12\x43\n\x12\x63\x61n_card_parameter\x18\x01 \x01(\x0b\x32\'.apollo.drivers.canbus.CANCardParameter\x12 \n\x11\x65nable_debug_mode\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\"\n\x13\x65nable_receiver_log\x18\x03 \x01(\x08:\x05\x66\x61lse\x12 \n\x11\x65nable_sender_log\x18\x04 \x01(\x08:\x05\x66\x61lse\"\xee\x05\n\tRadarConf\x12!\n\x12max_distance_valid\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x0fsensor_id_valid\x18\x02 \x01(\x08:\x05\x66\x61lse\x12 \n\x11radar_power_valid\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x11output_type_valid\x18\x04 \x01(\x08:\x04true\x12 \n\x12send_quality_valid\x18\x05 \x01(\x08:\x04true\x12!\n\x13send_ext_info_valid\x18\x06 \x01(\x08:\x04true\x12\x1f\n\x10sort_index_valid\x18\x07 \x01(\x08:\x05\x66\x61lse\x12 \n\x12store_in_nvm_valid\x18\x08 \x01(\x08:\x04true\x12\x1f\n\x10\x63trl_relay_valid\x18\t \x01(\x08:\x05\x66\x61lse\x12!\n\x13rcs_threshold_valid\x18\n \x01(\x08:\x04true\x12\x19\n\x0cmax_distance\x18\x0b \x01(\r:\x03\x32\x34\x38\x12\x14\n\tsensor_id\x18\x0c \x01(\r:\x01\x30\x12P\n\x0boutput_type\x18\r \x01(\x0e\x32&.apollo.drivers.conti_radar.OutputType:\x13OUTPUT_TYPE_OBJECTS\x12\x16\n\x0bradar_power\x18\x0e \x01(\r:\x01\x30\x12\x15\n\nctrl_relay\x18\x0f \x01(\r:\x01\x30\x12\x1b\n\rsend_ext_info\x18\x10 \x01(\x08:\x04true\x12\x1a\n\x0csend_quality\x18\x11 \x01(\x08:\x04true\x12\x15\n\nsort_index\x18\x12 \x01(\r:\x01\x30\x12\x17\n\x0cstore_in_nvm\x18\x13 \x01(\r:\x01\x31\x12W\n\rrcs_threshold\x18\x14 \x01(\x0e\x32(.apollo.drivers.conti_radar.RcsThreshold:\x16RCS_THRESHOLD_STANDARD\x12\x1b\n\x13input_send_interval\x18\x15 \x01(\x04\"\x99\x01\n\x0e\x43ontiRadarConf\x12\x35\n\x08\x63\x61n_conf\x18\x01 \x01(\x0b\x32#.apollo.drivers.conti_radar.CanConf\x12\x39\n\nradar_conf\x18\x02 \x01(\x0b\x32%.apollo.drivers.conti_radar.RadarConf\x12\x15\n\rradar_channel\x18\x03 \x01(\t*l\n\nOutputType\x12\x14\n\x10OUTPUT_TYPE_NONE\x10\x00\x12\x17\n\x13OUTPUT_TYPE_OBJECTS\x10\x01\x12\x18\n\x14OUTPUT_TYPE_CLUSTERS\x10\x02\x12\x15\n\x11OUTPUT_TYPE_ERROR\x10\x03*g\n\x0cRcsThreshold\x12\x1a\n\x16RCS_THRESHOLD_STANDARD\x10\x00\x12\"\n\x1eRCS_THRESHOLD_HIGH_SENSITIVITY\x10\x01\x12\x17\n\x13RCS_THRESHOLD_ERROR\x10\x02'
  ,
  dependencies=[modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2.DESCRIPTOR,])

_OUTPUTTYPE = _descriptor.EnumDescriptor(
  name='OutputType',
  full_name='apollo.drivers.conti_radar.OutputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_TYPE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_TYPE_OBJECTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_TYPE_CLUSTERS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_TYPE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1243,
  serialized_end=1351,
)
_sym_db.RegisterEnumDescriptor(_OUTPUTTYPE)

OutputType = enum_type_wrapper.EnumTypeWrapper(_OUTPUTTYPE)
_RCSTHRESHOLD = _descriptor.EnumDescriptor(
  name='RcsThreshold',
  full_name='apollo.drivers.conti_radar.RcsThreshold',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RCS_THRESHOLD_STANDARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RCS_THRESHOLD_HIGH_SENSITIVITY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RCS_THRESHOLD_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1353,
  serialized_end=1456,
)
_sym_db.RegisterEnumDescriptor(_RCSTHRESHOLD)

RcsThreshold = enum_type_wrapper.EnumTypeWrapper(_RCSTHRESHOLD)
OUTPUT_TYPE_NONE = 0
OUTPUT_TYPE_OBJECTS = 1
OUTPUT_TYPE_CLUSTERS = 2
OUTPUT_TYPE_ERROR = 3
RCS_THRESHOLD_STANDARD = 0
RCS_THRESHOLD_HIGH_SENSITIVITY = 1
RCS_THRESHOLD_ERROR = 2



_CANCONF = _descriptor.Descriptor(
  name='CanConf',
  full_name='apollo.drivers.conti_radar.CanConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_card_parameter', full_name='apollo.drivers.conti_radar.CanConf.can_card_parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_debug_mode', full_name='apollo.drivers.conti_radar.CanConf.enable_debug_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_receiver_log', full_name='apollo.drivers.conti_radar.CanConf.enable_receiver_log', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_sender_log', full_name='apollo.drivers.conti_radar.CanConf.enable_sender_log', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=332,
)


_RADARCONF = _descriptor.Descriptor(
  name='RadarConf',
  full_name='apollo.drivers.conti_radar.RadarConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_distance_valid', full_name='apollo.drivers.conti_radar.RadarConf.max_distance_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_id_valid', full_name='apollo.drivers.conti_radar.RadarConf.sensor_id_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_power_valid', full_name='apollo.drivers.conti_radar.RadarConf.radar_power_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_type_valid', full_name='apollo.drivers.conti_radar.RadarConf.output_type_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_quality_valid', full_name='apollo.drivers.conti_radar.RadarConf.send_quality_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_ext_info_valid', full_name='apollo.drivers.conti_radar.RadarConf.send_ext_info_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_index_valid', full_name='apollo.drivers.conti_radar.RadarConf.sort_index_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_in_nvm_valid', full_name='apollo.drivers.conti_radar.RadarConf.store_in_nvm_valid', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctrl_relay_valid', full_name='apollo.drivers.conti_radar.RadarConf.ctrl_relay_valid', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs_threshold_valid', full_name='apollo.drivers.conti_radar.RadarConf.rcs_threshold_valid', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_distance', full_name='apollo.drivers.conti_radar.RadarConf.max_distance', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=248,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_id', full_name='apollo.drivers.conti_radar.RadarConf.sensor_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_type', full_name='apollo.drivers.conti_radar.RadarConf.output_type', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_power', full_name='apollo.drivers.conti_radar.RadarConf.radar_power', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctrl_relay', full_name='apollo.drivers.conti_radar.RadarConf.ctrl_relay', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_ext_info', full_name='apollo.drivers.conti_radar.RadarConf.send_ext_info', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_quality', full_name='apollo.drivers.conti_radar.RadarConf.send_quality', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_index', full_name='apollo.drivers.conti_radar.RadarConf.sort_index', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_in_nvm', full_name='apollo.drivers.conti_radar.RadarConf.store_in_nvm', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs_threshold', full_name='apollo.drivers.conti_radar.RadarConf.rcs_threshold', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_send_interval', full_name='apollo.drivers.conti_radar.RadarConf.input_send_interval', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=1085,
)


_CONTIRADARCONF = _descriptor.Descriptor(
  name='ContiRadarConf',
  full_name='apollo.drivers.conti_radar.ContiRadarConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_conf', full_name='apollo.drivers.conti_radar.ContiRadarConf.can_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_conf', full_name='apollo.drivers.conti_radar.ContiRadarConf.radar_conf', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_channel', full_name='apollo.drivers.conti_radar.ContiRadarConf.radar_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1088,
  serialized_end=1241,
)

_CANCONF.fields_by_name['can_card_parameter'].message_type = modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2._CANCARDPARAMETER
_RADARCONF.fields_by_name['output_type'].enum_type = _OUTPUTTYPE
_RADARCONF.fields_by_name['rcs_threshold'].enum_type = _RCSTHRESHOLD
_CONTIRADARCONF.fields_by_name['can_conf'].message_type = _CANCONF
_CONTIRADARCONF.fields_by_name['radar_conf'].message_type = _RADARCONF
DESCRIPTOR.message_types_by_name['CanConf'] = _CANCONF
DESCRIPTOR.message_types_by_name['RadarConf'] = _RADARCONF
DESCRIPTOR.message_types_by_name['ContiRadarConf'] = _CONTIRADARCONF
DESCRIPTOR.enum_types_by_name['OutputType'] = _OUTPUTTYPE
DESCRIPTOR.enum_types_by_name['RcsThreshold'] = _RCSTHRESHOLD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CanConf = _reflection.GeneratedProtocolMessageType('CanConf', (_message.Message,), {
  'DESCRIPTOR' : _CANCONF,
  '__module__' : 'modules.drivers.radar.conti_radar.proto.conti_radar_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.conti_radar.CanConf)
  })
_sym_db.RegisterMessage(CanConf)

RadarConf = _reflection.GeneratedProtocolMessageType('RadarConf', (_message.Message,), {
  'DESCRIPTOR' : _RADARCONF,
  '__module__' : 'modules.drivers.radar.conti_radar.proto.conti_radar_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.conti_radar.RadarConf)
  })
_sym_db.RegisterMessage(RadarConf)

ContiRadarConf = _reflection.GeneratedProtocolMessageType('ContiRadarConf', (_message.Message,), {
  'DESCRIPTOR' : _CONTIRADARCONF,
  '__module__' : 'modules.drivers.radar.conti_radar.proto.conti_radar_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.conti_radar.ContiRadarConf)
  })
_sym_db.RegisterMessage(ContiRadarConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/util/testdata/simple.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/util/testdata/simple.proto',
  package='apollo.common.util.test',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/common/util/testdata/simple.proto\x12\x17\x61pollo.common.util.test\x1a!modules/common/proto/header.proto\"U\n\rSimpleMessage\x12\x0f\n\x07integer\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12%\n\x06header\x18\x03 \x01(\x0b\x32\x15.apollo.common.Header\"P\n\x15SimpleRepeatedMessage\x12\x37\n\x07message\x18\x01 \x03(\x0b\x32&.apollo.common.util.test.SimpleMessage'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_SIMPLEMESSAGE = _descriptor.Descriptor(
  name='SimpleMessage',
  full_name='apollo.common.util.test.SimpleMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='integer', full_name='apollo.common.util.test.SimpleMessage.integer', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='apollo.common.util.test.SimpleMessage.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.common.util.test.SimpleMessage.header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=190,
)


_SIMPLEREPEATEDMESSAGE = _descriptor.Descriptor(
  name='SimpleRepeatedMessage',
  full_name='apollo.common.util.test.SimpleRepeatedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='apollo.common.util.test.SimpleRepeatedMessage.message', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=272,
)

_SIMPLEMESSAGE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_SIMPLEREPEATEDMESSAGE.fields_by_name['message'].message_type = _SIMPLEMESSAGE
DESCRIPTOR.message_types_by_name['SimpleMessage'] = _SIMPLEMESSAGE
DESCRIPTOR.message_types_by_name['SimpleRepeatedMessage'] = _SIMPLEREPEATEDMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimpleMessage = _reflection.GeneratedProtocolMessageType('SimpleMessage', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEMESSAGE,
  '__module__' : 'modules.common.util.testdata.simple_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.util.test.SimpleMessage)
  })
_sym_db.RegisterMessage(SimpleMessage)

SimpleRepeatedMessage = _reflection.GeneratedProtocolMessageType('SimpleRepeatedMessage', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEREPEATEDMESSAGE,
  '__module__' : 'modules.common.util.testdata.simple_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.util.test.SimpleRepeatedMessage)
  })
_sym_db.RegisterMessage(SimpleRepeatedMessage)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/routing/proto/poi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/routing/proto/poi.proto',
  package='apollo.routing',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fmodules/routing/proto/poi.proto\x12\x0e\x61pollo.routing\x1a#modules/routing/proto/routing.proto\"\x99\x01\n\x08Landmark\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x08waypoint\x18\x02 \x03(\x0b\x32\x1c.apollo.routing.LaneWaypoint\x12\x1c\n\x10parking_space_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x31\n\x0cparking_info\x18\x04 \x01(\x0b\x32\x1b.apollo.routing.ParkingInfo\"1\n\x03POI\x12*\n\x08landmark\x18\x01 \x03(\x0b\x32\x18.apollo.routing.Landmark'
  ,
  dependencies=[modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])




_LANDMARK = _descriptor.Descriptor(
  name='Landmark',
  full_name='apollo.routing.Landmark',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.routing.Landmark.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waypoint', full_name='apollo.routing.Landmark.waypoint', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space_id', full_name='apollo.routing.Landmark.parking_space_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_info', full_name='apollo.routing.Landmark.parking_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=242,
)


_POI = _descriptor.Descriptor(
  name='POI',
  full_name='apollo.routing.POI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='landmark', full_name='apollo.routing.POI.landmark', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=293,
)

_LANDMARK.fields_by_name['waypoint'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._LANEWAYPOINT
_LANDMARK.fields_by_name['parking_info'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._PARKINGINFO
_POI.fields_by_name['landmark'].message_type = _LANDMARK
DESCRIPTOR.message_types_by_name['Landmark'] = _LANDMARK
DESCRIPTOR.message_types_by_name['POI'] = _POI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Landmark = _reflection.GeneratedProtocolMessageType('Landmark', (_message.Message,), {
  'DESCRIPTOR' : _LANDMARK,
  '__module__' : 'modules.routing.proto.poi_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.Landmark)
  })
_sym_db.RegisterMessage(Landmark)

POI = _reflection.GeneratedProtocolMessageType('POI', (_message.Message,), {
  'DESCRIPTOR' : _POI,
  '__module__' : 'modules.routing.proto.poi_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.POI)
  })
_sym_db.RegisterMessage(POI)


_LANDMARK.fields_by_name['parking_space_id']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/data/tools/smart_recorder/proto/smart_recorder_triggers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/data/tools/smart_recorder/proto/smart_recorder_triggers.proto',
  package='apollo.data',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEmodules/data/tools/smart_recorder/proto/smart_recorder_triggers.proto\x12\x0b\x61pollo.data\"L\n\x14RecordSegmentSetting\x12\x19\n\x0csize_segment\x18\x01 \x01(\x05:\x03\x35\x30\x30\x12\x19\n\x0ctime_segment\x18\x02 \x01(\x05:\x03\x31\x38\x30\"r\n\x07Trigger\x12\x14\n\x0ctrigger_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x15\n\rbackward_time\x18\x03 \x01(\x01\x12\x14\n\x0c\x66orward_time\x18\x04 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\xd4\x01\n\x12SmartRecordTrigger\x12:\n\x0fsegment_setting\x18\x01 \x01(\x0b\x32!.apollo.data.RecordSegmentSetting\x12&\n\x08triggers\x18\x02 \x03(\x0b\x32\x14.apollo.data.Trigger\x12\x1d\n\x11max_backward_time\x18\x03 \x01(\x01:\x02\x33\x30\x12\x1c\n\x11min_restore_chunk\x18\x04 \x01(\x01:\x01\x35\x12\x1d\n\x15trigger_log_file_path\x18\x05 \x01(\t'
)




_RECORDSEGMENTSETTING = _descriptor.Descriptor(
  name='RecordSegmentSetting',
  full_name='apollo.data.RecordSegmentSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size_segment', full_name='apollo.data.RecordSegmentSetting.size_segment', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_segment', full_name='apollo.data.RecordSegmentSetting.time_segment', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=180,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=162,
)


_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='apollo.data.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_name', full_name='apollo.data.Trigger.trigger_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.data.Trigger.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backward_time', full_name='apollo.data.Trigger.backward_time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_time', full_name='apollo.data.Trigger.forward_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='apollo.data.Trigger.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=278,
)


_SMARTRECORDTRIGGER = _descriptor.Descriptor(
  name='SmartRecordTrigger',
  full_name='apollo.data.SmartRecordTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment_setting', full_name='apollo.data.SmartRecordTrigger.segment_setting', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggers', full_name='apollo.data.SmartRecordTrigger.triggers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_backward_time', full_name='apollo.data.SmartRecordTrigger.max_backward_time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(30),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_restore_chunk', full_name='apollo.data.SmartRecordTrigger.min_restore_chunk', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_log_file_path', full_name='apollo.data.SmartRecordTrigger.trigger_log_file_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=493,
)

_SMARTRECORDTRIGGER.fields_by_name['segment_setting'].message_type = _RECORDSEGMENTSETTING
_SMARTRECORDTRIGGER.fields_by_name['triggers'].message_type = _TRIGGER
DESCRIPTOR.message_types_by_name['RecordSegmentSetting'] = _RECORDSEGMENTSETTING
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['SmartRecordTrigger'] = _SMARTRECORDTRIGGER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecordSegmentSetting = _reflection.GeneratedProtocolMessageType('RecordSegmentSetting', (_message.Message,), {
  'DESCRIPTOR' : _RECORDSEGMENTSETTING,
  '__module__' : 'modules.data.tools.smart_recorder.proto.smart_recorder_triggers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.RecordSegmentSetting)
  })
_sym_db.RegisterMessage(RecordSegmentSetting)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'modules.data.tools.smart_recorder.proto.smart_recorder_triggers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

SmartRecordTrigger = _reflection.GeneratedProtocolMessageType('SmartRecordTrigger', (_message.Message,), {
  'DESCRIPTOR' : _SMARTRECORDTRIGGER,
  '__module__' : 'modules.data.tools.smart_recorder.proto.smart_recorder_triggers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.SmartRecordTrigger)
  })
_sym_db.RegisterMessage(SmartRecordTrigger)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/zhongyun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/zhongyun.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/canbus/proto/zhongyun.proto\x12\rapollo.canbus\"\xc5\x03\n\x0fGear_control_a1\x12O\n\x11gear_state_target\x18\x01 \x01(\x0e\x32\x34.apollo.canbus.Gear_control_a1.Gear_state_targetType\x12S\n\x13gear_enable_control\x18\x02 \x01(\x0e\x32\x36.apollo.canbus.Gear_control_a1.Gear_enable_controlType\"\x9a\x01\n\x15Gear_state_targetType\x12\x17\n\x13GEAR_STATE_TARGET_P\x10\x01\x12\x17\n\x13GEAR_STATE_TARGET_N\x10\x02\x12\x17\n\x13GEAR_STATE_TARGET_D\x10\x03\x12\x17\n\x13GEAR_STATE_TARGET_R\x10\x04\x12\x1d\n\x19GEAR_STATE_TARGET_INVALID\x10\x05\"o\n\x17Gear_enable_controlType\x12*\n&GEAR_ENABLE_CONTROL_GEAR_MANUALCONTROL\x10\x00\x12(\n$GEAR_ENABLE_CONTROL_GEAR_AUTOCONTROL\x10\x01\"\xf0\x01\n\x11Torque_control_a3\x12\x15\n\rdriven_torque\x18\x01 \x01(\x01\x12Y\n\x15\x64riven_enable_control\x18\x02 \x01(\x0e\x32:.apollo.canbus.Torque_control_a3.Driven_enable_controlType\"i\n\x19\x44riven_enable_controlType\x12&\n\"DRIVEN_ENABLE_CONTROL_DRIVE_MANUAL\x10\x00\x12$\n DRIVEN_ENABLE_CONTROL_DRIVE_AUTO\x10\x01\"\x95\x02\n\x13Steering_control_a2\x12\x17\n\x0fsteering_target\x18\x01 \x01(\x01\x12_\n\x17steering_enable_control\x18\x02 \x01(\x0e\x32>.apollo.canbus.Steering_control_a2.Steering_enable_controlType\"\x83\x01\n\x1bSteering_enable_controlType\x12\x32\n.STEERING_ENABLE_CONTROL_STEERING_MANUALCONTROL\x10\x00\x12\x30\n,STEERING_ENABLE_CONTROL_STEERING_AUTOCONTROL\x10\x01\"\x96\x03\n\x12Parking_control_a5\x12L\n\x0eparking_target\x18\x01 \x01(\x0e\x32\x34.apollo.canbus.Parking_control_a5.Parking_targetType\x12\\\n\x16parking_enable_control\x18\x02 \x01(\x0e\x32<.apollo.canbus.Parking_control_a5.Parking_enable_controlType\"T\n\x12Parking_targetType\x12\x1a\n\x16PARKING_TARGET_RELEASE\x10\x00\x12\"\n\x1ePARKING_TARGET_PARKING_TRIGGER\x10\x01\"~\n\x1aParking_enable_controlType\x12\x30\n,PARKING_ENABLE_CONTROL_PARKING_MANUALCONTROL\x10\x00\x12.\n*PARKING_ENABLE_CONTROL_PARKING_AUTOCONTROL\x10\x01\"\xe8\x01\n\x10\x42rake_control_a4\x12\x14\n\x0c\x62rake_torque\x18\x01 \x01(\x01\x12V\n\x14\x62rake_enable_control\x18\x02 \x01(\x0e\x32\x38.apollo.canbus.Brake_control_a4.Brake_enable_controlType\"f\n\x18\x42rake_enable_controlType\x12%\n!BRAKE_ENABLE_CONTROL_BRAKE_MANUAL\x10\x00\x12#\n\x1f\x42RAKE_ENABLE_CONTROL_BRAKE_AUTO\x10\x01\"\x80\n\n\x18\x45nable_state_feedback_c3\x12^\n\x14parking_enable_state\x18\x01 \x01(\x0e\x32@.apollo.canbus.Enable_state_feedback_c3.Parking_enable_stateType\x12`\n\x15steering_enable_state\x18\x02 \x01(\x0e\x32\x41.apollo.canbus.Enable_state_feedback_c3.Steering_enable_stateType\x12Z\n\x12gear_enable_actual\x18\x03 \x01(\x0e\x32>.apollo.canbus.Enable_state_feedback_c3.Gear_enable_actualType\x12\\\n\x13\x64riven_enable_state\x18\x04 \x01(\x0e\x32?.apollo.canbus.Enable_state_feedback_c3.Driven_enable_stateType\x12Z\n\x12\x62rake_enable_state\x18\x05 \x01(\x0e\x32>.apollo.canbus.Enable_state_feedback_c3.Brake_enable_stateType\"\xa3\x01\n\x18Parking_enable_stateType\x12.\n*PARKING_ENABLE_STATE_PARKING_MANUALCONTROL\x10\x00\x12,\n(PARKING_ENABLE_STATE_PARKING_AUTOCONTROL\x10\x01\x12)\n%PARKING_ENABLE_STATE_PARKING_TAKEOVER\x10\x02\"\xb1\x01\n\x19Steering_enable_stateType\x12\x30\n,STEERING_ENABLE_STATE_STEERING_MANUALCONTROL\x10\x00\x12.\n*STEERING_ENABLE_STATE_STEERING_AUTOCONTROL\x10\x01\x12\x32\n.STEERING_ENABLE_STATE_STEERING_MANUAL_TAKEOVER\x10\x02\"\x99\x01\n\x16Gear_enable_actualType\x12)\n%GEAR_ENABLE_ACTUAL_GEAR_MANUALCONTROL\x10\x00\x12\'\n#GEAR_ENABLE_ACTUAL_GEAR_AUTOCONTROL\x10\x01\x12+\n\'GEAR_ENABLE_ACTUAL_GEAR_MANUAL_TAKEOVER\x10\x02\"\x8b\x01\n\x17\x44riven_enable_stateType\x12$\n DRIVEN_ENABLE_STATE_DRIVE_MANUAL\x10\x00\x12\"\n\x1e\x44RIVEN_ENABLE_STATE_DRIVE_AUTO\x10\x01\x12&\n\"DRIVEN_ENABLE_STATE_DRIVE_TAKEOVER\x10\x02\"\x87\x01\n\x16\x42rake_enable_stateType\x12#\n\x1f\x42RAKE_ENABLE_STATE_BRAKE_MANUAL\x10\x00\x12!\n\x1d\x42RAKE_ENABLE_STATE_BRAKE_AUTO\x10\x01\x12%\n!BRAKE_ENABLE_STATE_BRAKE_TAKEOVER\x10\x02\"\x85\x04\n\x19Vehicle_state_feedback_c1\x12S\n\x0eparking_actual\x18\x01 \x01(\x0e\x32;.apollo.canbus.Vehicle_state_feedback_c1.Parking_actualType\x12\x1d\n\x15\x62rake_torque_feedback\x18\x02 \x01(\x01\x12Y\n\x11gear_state_actual\x18\x03 \x01(\x0e\x32>.apollo.canbus.Vehicle_state_feedback_c1.Gear_state_actualType\x12\x17\n\x0fsteering_actual\x18\x04 \x01(\x01\x12\r\n\x05speed\x18\x05 \x01(\x01\"T\n\x12Parking_actualType\x12\x1a\n\x16PARKING_ACTUAL_RELEASE\x10\x00\x12\"\n\x1ePARKING_ACTUAL_PARKING_TRIGGER\x10\x01\"\x9a\x01\n\x15Gear_state_actualType\x12\x17\n\x13GEAR_STATE_ACTUAL_P\x10\x01\x12\x17\n\x13GEAR_STATE_ACTUAL_N\x10\x02\x12\x17\n\x13GEAR_STATE_ACTUAL_D\x10\x03\x12\x17\n\x13GEAR_STATE_ACTUAL_R\x10\x04\x12\x1d\n\x19GEAR_STATE_ACTUAL_INVALID\x10\x05\"\xc9\x06\n\x0e\x45rror_state_e1\x12L\n\x10\x62rake_error_code\x18\x01 \x01(\x0e\x32\x32.apollo.canbus.Error_state_e1.Brake_error_codeType\x12N\n\x11\x64riven_error_code\x18\x02 \x01(\x0e\x32\x33.apollo.canbus.Error_state_e1.Driven_error_codeType\x12R\n\x13steering_error_code\x18\x03 \x01(\x0e\x32\x35.apollo.canbus.Error_state_e1.Steering_error_codeType\x12P\n\x12parking_error_code\x18\x04 \x01(\x0e\x32\x34.apollo.canbus.Error_state_e1.Parking_error_codeType\x12H\n\x0egear_error_msg\x18\x05 \x01(\x0e\x32\x30.apollo.canbus.Error_state_e1.Gear_error_msgType\"Q\n\x14\x42rake_error_codeType\x12\x1d\n\x19\x42RAKE_ERROR_CODE_NO_ERROR\x10\x00\x12\x1a\n\x16\x42RAKE_ERROR_CODE_ERROR\x10\x01\"T\n\x15\x44riven_error_codeType\x12\x1e\n\x1a\x44RIVEN_ERROR_CODE_NO_ERROR\x10\x00\x12\x1b\n\x17\x44RIVEN_ERROR_CODE_ERROR\x10\x01\"Z\n\x17Steering_error_codeType\x12 \n\x1cSTEERING_ERROR_CODE_NO_ERROR\x10\x00\x12\x1d\n\x19STEERING_ERROR_CODE_ERROR\x10\x01\"W\n\x16Parking_error_codeType\x12\x1f\n\x1bPARKING_ERROR_CODE_NO_ERROR\x10\x00\x12\x1c\n\x18PARKING_ERROR_CODE_ERROR\x10\x01\"K\n\x12Gear_error_msgType\x12\x1b\n\x17GEAR_ERROR_MSG_NO_ERROR\x10\x00\x12\x18\n\x14GEAR_ERROR_MSG_ERROR\x10\x01\"R\n\x1bVehicle_state_feedback_2_c4\x12\x13\n\x0bmotor_speed\x18\x01 \x01(\x05\x12\x1e\n\x16\x64riven_torque_feedback\x18\x02 \x01(\x01\"\xdb\x04\n\x08Zhongyun\x12\x37\n\x0fgear_control_a1\x18\x01 \x01(\x0b\x32\x1e.apollo.canbus.Gear_control_a1\x12;\n\x11torque_control_a3\x18\x02 \x01(\x0b\x32 .apollo.canbus.Torque_control_a3\x12?\n\x13steering_control_a2\x18\x03 \x01(\x0b\x32\".apollo.canbus.Steering_control_a2\x12=\n\x12parking_control_a5\x18\x04 \x01(\x0b\x32!.apollo.canbus.Parking_control_a5\x12\x39\n\x10\x62rake_control_a4\x18\x05 \x01(\x0b\x32\x1f.apollo.canbus.Brake_control_a4\x12I\n\x18\x65nable_state_feedback_c3\x18\x06 \x01(\x0b\x32\'.apollo.canbus.Enable_state_feedback_c3\x12K\n\x19vehicle_state_feedback_c1\x18\x07 \x01(\x0b\x32(.apollo.canbus.Vehicle_state_feedback_c1\x12\x35\n\x0e\x65rror_state_e1\x18\x08 \x01(\x0b\x32\x1d.apollo.canbus.Error_state_e1\x12O\n\x1bvehicle_state_feedback_2_c4\x18\t \x01(\x0b\x32*.apollo.canbus.Vehicle_state_feedback_2_c4'
)



_GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Gear_state_targetType',
  full_name='apollo.canbus.Gear_control_a1.Gear_state_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_P', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_N', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_D', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_R', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_INVALID', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=241,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE)

_GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Gear_enable_controlType',
  full_name='apollo.canbus.Gear_control_a1.Gear_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_CONTROL_GEAR_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_CONTROL_GEAR_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=397,
  serialized_end=508,
)
_sym_db.RegisterEnumDescriptor(_GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE)

_TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Driven_enable_controlType',
  full_name='apollo.canbus.Torque_control_a3.Driven_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_CONTROL_DRIVE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_CONTROL_DRIVE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=646,
  serialized_end=751,
)
_sym_db.RegisterEnumDescriptor(_TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE)

_STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Steering_enable_controlType',
  full_name='apollo.canbus.Steering_control_a2.Steering_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_CONTROL_STEERING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_CONTROL_STEERING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=900,
  serialized_end=1031,
)
_sym_db.RegisterEnumDescriptor(_STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE)

_PARKING_CONTROL_A5_PARKING_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Parking_targetType',
  full_name='apollo.canbus.Parking_control_a5.Parking_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_TARGET_RELEASE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_TARGET_PARKING_TRIGGER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1228,
  serialized_end=1312,
)
_sym_db.RegisterEnumDescriptor(_PARKING_CONTROL_A5_PARKING_TARGETTYPE)

_PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Parking_enable_controlType',
  full_name='apollo.canbus.Parking_control_a5.Parking_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_CONTROL_PARKING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_CONTROL_PARKING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1314,
  serialized_end=1440,
)
_sym_db.RegisterEnumDescriptor(_PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE)

_BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Brake_enable_controlType',
  full_name='apollo.canbus.Brake_control_a4.Brake_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_CONTROL_BRAKE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_CONTROL_BRAKE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1573,
  serialized_end=1675,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE)

_ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Parking_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Parking_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_STATE_PARKING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_STATE_PARKING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_STATE_PARKING_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2179,
  serialized_end=2342,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE)

_ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Steering_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Steering_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_STATE_STEERING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_STATE_STEERING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_STATE_STEERING_MANUAL_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2345,
  serialized_end=2522,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE)

_ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Gear_enable_actualType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Gear_enable_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_ACTUAL_GEAR_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_ACTUAL_GEAR_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_ACTUAL_GEAR_MANUAL_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2525,
  serialized_end=2678,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE)

_ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Driven_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Driven_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_STATE_DRIVE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_STATE_DRIVE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_STATE_DRIVE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2681,
  serialized_end=2820,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE)

_ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Brake_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Brake_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_STATE_BRAKE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_STATE_BRAKE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_STATE_BRAKE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2823,
  serialized_end=2958,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE)

_VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Parking_actualType',
  full_name='apollo.canbus.Vehicle_state_feedback_c1.Parking_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ACTUAL_RELEASE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ACTUAL_PARKING_TRIGGER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3237,
  serialized_end=3321,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE)

_VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Gear_state_actualType',
  full_name='apollo.canbus.Vehicle_state_feedback_c1.Gear_state_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_P', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_N', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_D', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_R', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_INVALID', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3324,
  serialized_end=3478,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE)

_ERROR_STATE_E1_BRAKE_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Brake_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Brake_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3897,
  serialized_end=3978,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_BRAKE_ERROR_CODETYPE)

_ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Driven_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Driven_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3980,
  serialized_end=4064,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE)

_ERROR_STATE_E1_STEERING_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Steering_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Steering_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERING_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4066,
  serialized_end=4156,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_STEERING_ERROR_CODETYPE)

_ERROR_STATE_E1_PARKING_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Parking_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Parking_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4158,
  serialized_end=4245,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_PARKING_ERROR_CODETYPE)

_ERROR_STATE_E1_GEAR_ERROR_MSGTYPE = _descriptor.EnumDescriptor(
  name='Gear_error_msgType',
  full_name='apollo.canbus.Error_state_e1.Gear_error_msgType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ERROR_MSG_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ERROR_MSG_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4247,
  serialized_end=4322,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_GEAR_ERROR_MSGTYPE)


_GEAR_CONTROL_A1 = _descriptor.Descriptor(
  name='Gear_control_a1',
  full_name='apollo.canbus.Gear_control_a1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_state_target', full_name='apollo.canbus.Gear_control_a1.gear_state_target', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_enable_control', full_name='apollo.canbus.Gear_control_a1.gear_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE,
    _GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=508,
)


_TORQUE_CONTROL_A3 = _descriptor.Descriptor(
  name='Torque_control_a3',
  full_name='apollo.canbus.Torque_control_a3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driven_torque', full_name='apollo.canbus.Torque_control_a3.driven_torque', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_enable_control', full_name='apollo.canbus.Torque_control_a3.driven_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=751,
)


_STEERING_CONTROL_A2 = _descriptor.Descriptor(
  name='Steering_control_a2',
  full_name='apollo.canbus.Steering_control_a2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steering_target', full_name='apollo.canbus.Steering_control_a2.steering_target', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_enable_control', full_name='apollo.canbus.Steering_control_a2.steering_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=1031,
)


_PARKING_CONTROL_A5 = _descriptor.Descriptor(
  name='Parking_control_a5',
  full_name='apollo.canbus.Parking_control_a5',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_target', full_name='apollo.canbus.Parking_control_a5.parking_target', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_enable_control', full_name='apollo.canbus.Parking_control_a5.parking_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARKING_CONTROL_A5_PARKING_TARGETTYPE,
    _PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1440,
)


_BRAKE_CONTROL_A4 = _descriptor.Descriptor(
  name='Brake_control_a4',
  full_name='apollo.canbus.Brake_control_a4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_torque', full_name='apollo.canbus.Brake_control_a4.brake_torque', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_enable_control', full_name='apollo.canbus.Brake_control_a4.brake_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1675,
)


_ENABLE_STATE_FEEDBACK_C3 = _descriptor.Descriptor(
  name='Enable_state_feedback_c3',
  full_name='apollo.canbus.Enable_state_feedback_c3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.parking_enable_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.steering_enable_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_enable_actual', full_name='apollo.canbus.Enable_state_feedback_c3.gear_enable_actual', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.driven_enable_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.brake_enable_state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE,
    _ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE,
    _ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE,
    _ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE,
    _ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=2958,
)


_VEHICLE_STATE_FEEDBACK_C1 = _descriptor.Descriptor(
  name='Vehicle_state_feedback_c1',
  full_name='apollo.canbus.Vehicle_state_feedback_c1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_actual', full_name='apollo.canbus.Vehicle_state_feedback_c1.parking_actual', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_torque_feedback', full_name='apollo.canbus.Vehicle_state_feedback_c1.brake_torque_feedback', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_state_actual', full_name='apollo.canbus.Vehicle_state_feedback_c1.gear_state_actual', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_actual', full_name='apollo.canbus.Vehicle_state_feedback_c1.steering_actual', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.canbus.Vehicle_state_feedback_c1.speed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE,
    _VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2961,
  serialized_end=3478,
)


_ERROR_STATE_E1 = _descriptor.Descriptor(
  name='Error_state_e1',
  full_name='apollo.canbus.Error_state_e1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_error_code', full_name='apollo.canbus.Error_state_e1.brake_error_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_error_code', full_name='apollo.canbus.Error_state_e1.driven_error_code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_error_code', full_name='apollo.canbus.Error_state_e1.steering_error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_error_code', full_name='apollo.canbus.Error_state_e1.parking_error_code', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_error_msg', full_name='apollo.canbus.Error_state_e1.gear_error_msg', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERROR_STATE_E1_BRAKE_ERROR_CODETYPE,
    _ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE,
    _ERROR_STATE_E1_STEERING_ERROR_CODETYPE,
    _ERROR_STATE_E1_PARKING_ERROR_CODETYPE,
    _ERROR_STATE_E1_GEAR_ERROR_MSGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3481,
  serialized_end=4322,
)


_VEHICLE_STATE_FEEDBACK_2_C4 = _descriptor.Descriptor(
  name='Vehicle_state_feedback_2_c4',
  full_name='apollo.canbus.Vehicle_state_feedback_2_c4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_speed', full_name='apollo.canbus.Vehicle_state_feedback_2_c4.motor_speed', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_torque_feedback', full_name='apollo.canbus.Vehicle_state_feedback_2_c4.driven_torque_feedback', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4324,
  serialized_end=4406,
)


_ZHONGYUN = _descriptor.Descriptor(
  name='Zhongyun',
  full_name='apollo.canbus.Zhongyun',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_control_a1', full_name='apollo.canbus.Zhongyun.gear_control_a1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_control_a3', full_name='apollo.canbus.Zhongyun.torque_control_a3', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_control_a2', full_name='apollo.canbus.Zhongyun.steering_control_a2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_control_a5', full_name='apollo.canbus.Zhongyun.parking_control_a5', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_control_a4', full_name='apollo.canbus.Zhongyun.brake_control_a4', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_state_feedback_c3', full_name='apollo.canbus.Zhongyun.enable_state_feedback_c3', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_state_feedback_c1', full_name='apollo.canbus.Zhongyun.vehicle_state_feedback_c1', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state_e1', full_name='apollo.canbus.Zhongyun.error_state_e1', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_state_feedback_2_c4', full_name='apollo.canbus.Zhongyun.vehicle_state_feedback_2_c4', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4409,
  serialized_end=5012,
)

_GEAR_CONTROL_A1.fields_by_name['gear_state_target'].enum_type = _GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE
_GEAR_CONTROL_A1.fields_by_name['gear_enable_control'].enum_type = _GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE
_GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE.containing_type = _GEAR_CONTROL_A1
_GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE.containing_type = _GEAR_CONTROL_A1
_TORQUE_CONTROL_A3.fields_by_name['driven_enable_control'].enum_type = _TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE
_TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE.containing_type = _TORQUE_CONTROL_A3
_STEERING_CONTROL_A2.fields_by_name['steering_enable_control'].enum_type = _STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE
_STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE.containing_type = _STEERING_CONTROL_A2
_PARKING_CONTROL_A5.fields_by_name['parking_target'].enum_type = _PARKING_CONTROL_A5_PARKING_TARGETTYPE
_PARKING_CONTROL_A5.fields_by_name['parking_enable_control'].enum_type = _PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE
_PARKING_CONTROL_A5_PARKING_TARGETTYPE.containing_type = _PARKING_CONTROL_A5
_PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE.containing_type = _PARKING_CONTROL_A5
_BRAKE_CONTROL_A4.fields_by_name['brake_enable_control'].enum_type = _BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE
_BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE.containing_type = _BRAKE_CONTROL_A4
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['parking_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['steering_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['gear_enable_actual'].enum_type = _ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['driven_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['brake_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_VEHICLE_STATE_FEEDBACK_C1.fields_by_name['parking_actual'].enum_type = _VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE
_VEHICLE_STATE_FEEDBACK_C1.fields_by_name['gear_state_actual'].enum_type = _VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE
_VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE.containing_type = _VEHICLE_STATE_FEEDBACK_C1
_VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE.containing_type = _VEHICLE_STATE_FEEDBACK_C1
_ERROR_STATE_E1.fields_by_name['brake_error_code'].enum_type = _ERROR_STATE_E1_BRAKE_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['driven_error_code'].enum_type = _ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['steering_error_code'].enum_type = _ERROR_STATE_E1_STEERING_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['parking_error_code'].enum_type = _ERROR_STATE_E1_PARKING_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['gear_error_msg'].enum_type = _ERROR_STATE_E1_GEAR_ERROR_MSGTYPE
_ERROR_STATE_E1_BRAKE_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_STEERING_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_PARKING_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_GEAR_ERROR_MSGTYPE.containing_type = _ERROR_STATE_E1
_ZHONGYUN.fields_by_name['gear_control_a1'].message_type = _GEAR_CONTROL_A1
_ZHONGYUN.fields_by_name['torque_control_a3'].message_type = _TORQUE_CONTROL_A3
_ZHONGYUN.fields_by_name['steering_control_a2'].message_type = _STEERING_CONTROL_A2
_ZHONGYUN.fields_by_name['parking_control_a5'].message_type = _PARKING_CONTROL_A5
_ZHONGYUN.fields_by_name['brake_control_a4'].message_type = _BRAKE_CONTROL_A4
_ZHONGYUN.fields_by_name['enable_state_feedback_c3'].message_type = _ENABLE_STATE_FEEDBACK_C3
_ZHONGYUN.fields_by_name['vehicle_state_feedback_c1'].message_type = _VEHICLE_STATE_FEEDBACK_C1
_ZHONGYUN.fields_by_name['error_state_e1'].message_type = _ERROR_STATE_E1
_ZHONGYUN.fields_by_name['vehicle_state_feedback_2_c4'].message_type = _VEHICLE_STATE_FEEDBACK_2_C4
DESCRIPTOR.message_types_by_name['Gear_control_a1'] = _GEAR_CONTROL_A1
DESCRIPTOR.message_types_by_name['Torque_control_a3'] = _TORQUE_CONTROL_A3
DESCRIPTOR.message_types_by_name['Steering_control_a2'] = _STEERING_CONTROL_A2
DESCRIPTOR.message_types_by_name['Parking_control_a5'] = _PARKING_CONTROL_A5
DESCRIPTOR.message_types_by_name['Brake_control_a4'] = _BRAKE_CONTROL_A4
DESCRIPTOR.message_types_by_name['Enable_state_feedback_c3'] = _ENABLE_STATE_FEEDBACK_C3
DESCRIPTOR.message_types_by_name['Vehicle_state_feedback_c1'] = _VEHICLE_STATE_FEEDBACK_C1
DESCRIPTOR.message_types_by_name['Error_state_e1'] = _ERROR_STATE_E1
DESCRIPTOR.message_types_by_name['Vehicle_state_feedback_2_c4'] = _VEHICLE_STATE_FEEDBACK_2_C4
DESCRIPTOR.message_types_by_name['Zhongyun'] = _ZHONGYUN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gear_control_a1 = _reflection.GeneratedProtocolMessageType('Gear_control_a1', (_message.Message,), {
  'DESCRIPTOR' : _GEAR_CONTROL_A1,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear_control_a1)
  })
_sym_db.RegisterMessage(Gear_control_a1)

Torque_control_a3 = _reflection.GeneratedProtocolMessageType('Torque_control_a3', (_message.Message,), {
  'DESCRIPTOR' : _TORQUE_CONTROL_A3,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Torque_control_a3)
  })
_sym_db.RegisterMessage(Torque_control_a3)

Steering_control_a2 = _reflection.GeneratedProtocolMessageType('Steering_control_a2', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_CONTROL_A2,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_control_a2)
  })
_sym_db.RegisterMessage(Steering_control_a2)

Parking_control_a5 = _reflection.GeneratedProtocolMessageType('Parking_control_a5', (_message.Message,), {
  'DESCRIPTOR' : _PARKING_CONTROL_A5,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Parking_control_a5)
  })
_sym_db.RegisterMessage(Parking_control_a5)

Brake_control_a4 = _reflection.GeneratedProtocolMessageType('Brake_control_a4', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_CONTROL_A4,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_control_a4)
  })
_sym_db.RegisterMessage(Brake_control_a4)

Enable_state_feedback_c3 = _reflection.GeneratedProtocolMessageType('Enable_state_feedback_c3', (_message.Message,), {
  'DESCRIPTOR' : _ENABLE_STATE_FEEDBACK_C3,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Enable_state_feedback_c3)
  })
_sym_db.RegisterMessage(Enable_state_feedback_c3)

Vehicle_state_feedback_c1 = _reflection.GeneratedProtocolMessageType('Vehicle_state_feedback_c1', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE_STATE_FEEDBACK_C1,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vehicle_state_feedback_c1)
  })
_sym_db.RegisterMessage(Vehicle_state_feedback_c1)

Error_state_e1 = _reflection.GeneratedProtocolMessageType('Error_state_e1', (_message.Message,), {
  'DESCRIPTOR' : _ERROR_STATE_E1,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Error_state_e1)
  })
_sym_db.RegisterMessage(Error_state_e1)

Vehicle_state_feedback_2_c4 = _reflection.GeneratedProtocolMessageType('Vehicle_state_feedback_2_c4', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE_STATE_FEEDBACK_2_C4,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vehicle_state_feedback_2_c4)
  })
_sym_db.RegisterMessage(Vehicle_state_feedback_2_c4)

Zhongyun = _reflection.GeneratedProtocolMessageType('Zhongyun', (_message.Message,), {
  'DESCRIPTOR' : _ZHONGYUN,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Zhongyun)
  })
_sym_db.RegisterMessage(Zhongyun)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/lidar/proto/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.lidar.proto import hesai_config_pb2 as modules_dot_drivers_dot_lidar_dot_proto_dot_hesai__config__pb2
from modules.drivers.lidar.proto import velodyne_config_pb2 as modules_dot_drivers_dot_lidar_dot_proto_dot_velodyne__config__pb2
from modules.drivers.lidar.proto import lidar_parameter_pb2 as modules_dot_drivers_dot_lidar_dot_proto_dot_lidar__parameter__pb2
from modules.drivers.lidar.proto import robosense_config_pb2 as modules_dot_drivers_dot_lidar_dot_proto_dot_robosense__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/lidar/proto/config.proto',
  package='apollo.drivers.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/drivers/lidar/proto/config.proto\x12\x14\x61pollo.drivers.lidar\x1a.modules/drivers/lidar/proto/hesai_config.proto\x1a\x31modules/drivers/lidar/proto/velodyne_config.proto\x1a\x31modules/drivers/lidar/proto/lidar_parameter.proto\x1a\x32modules/drivers/lidar/proto/robosense_config.proto\"\xdd\x01\n\x06\x63onfig\x12>\n\x05\x62rand\x18\x01 \x01(\x0e\x32/.apollo.drivers.lidar.LidarParameter.LidarBrand\x12+\n\x05hesai\x18\x02 \x01(\x0b\x32\x1c.apollo.drivers.hesai.Config\x12\x33\n\trobosense\x18\x03 \x01(\x0b\x32 .apollo.drivers.robosense.Config\x12\x31\n\x08velodyne\x18\x04 \x01(\x0b\x32\x1f.apollo.drivers.velodyne.Config'
  ,
  dependencies=[modules_dot_drivers_dot_lidar_dot_proto_dot_hesai__config__pb2.DESCRIPTOR,modules_dot_drivers_dot_lidar_dot_proto_dot_velodyne__config__pb2.DESCRIPTOR,modules_dot_drivers_dot_lidar_dot_proto_dot_lidar__parameter__pb2.DESCRIPTOR,modules_dot_drivers_dot_lidar_dot_proto_dot_robosense__config__pb2.DESCRIPTOR,])




_CONFIG = _descriptor.Descriptor(
  name='config',
  full_name='apollo.drivers.lidar.config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brand', full_name='apollo.drivers.lidar.config.brand', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hesai', full_name='apollo.drivers.lidar.config.hesai', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robosense', full_name='apollo.drivers.lidar.config.robosense', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velodyne', full_name='apollo.drivers.lidar.config.velodyne', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=490,
)

_CONFIG.fields_by_name['brand'].enum_type = modules_dot_drivers_dot_lidar_dot_proto_dot_lidar__parameter__pb2._LIDARPARAMETER_LIDARBRAND
_CONFIG.fields_by_name['hesai'].message_type = modules_dot_drivers_dot_lidar_dot_proto_dot_hesai__config__pb2._CONFIG
_CONFIG.fields_by_name['robosense'].message_type = modules_dot_drivers_dot_lidar_dot_proto_dot_robosense__config__pb2._CONFIG
_CONFIG.fields_by_name['velodyne'].message_type = modules_dot_drivers_dot_lidar_dot_proto_dot_velodyne__config__pb2._CONFIG
DESCRIPTOR.message_types_by_name['config'] = _CONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

config = _reflection.GeneratedProtocolMessageType('config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'modules.drivers.lidar.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.lidar.config)
  })
_sym_db.RegisterMessage(config)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_obu_rsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_obu_rsi.proto',
  package='apollo.v2x.obu',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/v2x/proto/v2x_obu_rsi.proto\x12\x0e\x61pollo.v2x.obu\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"\xec\x01\n\x06ObuRsi\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x0e\n\x06rsu_id\x18\x02 \x01(\x0c\x12\x0e\n\x06rsi_id\x18\x03 \x01(\x05\x12\x12\n\nalter_type\x18\x04 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12)\n\tref_point\x18\x06 \x01(\x0b\x32\x16.apollo.common.Point2D\x12&\n\x06points\x18\x07 \x03(\x0b\x32\x16.apollo.common.Point2D\x12\x0e\n\x06radius\x18\x08 \x01(\x05\x12\x0f\n\x07msg_cnt\x18\t \x01(\x05'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_OBURSI = _descriptor.Descriptor(
  name='ObuRsi',
  full_name='apollo.v2x.obu.ObuRsi',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.v2x.obu.ObuRsi.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rsu_id', full_name='apollo.v2x.obu.ObuRsi.rsu_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rsi_id', full_name='apollo.v2x.obu.ObuRsi.rsi_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_type', full_name='apollo.v2x.obu.ObuRsi.alter_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='apollo.v2x.obu.ObuRsi.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point', full_name='apollo.v2x.obu.ObuRsi.ref_point', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='apollo.v2x.obu.ObuRsi.points', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='apollo.v2x.obu.ObuRsi.radius', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_cnt', full_name='apollo.v2x.obu.ObuRsi.msg_cnt', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=364,
)

_OBURSI.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_OBURSI.fields_by_name['ref_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_OBURSI.fields_by_name['points'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
DESCRIPTOR.message_types_by_name['ObuRsi'] = _OBURSI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObuRsi = _reflection.GeneratedProtocolMessageType('ObuRsi', (_message.Message,), {
  'DESCRIPTOR' : _OBURSI,
  '__module__' : 'modules.v2x.proto.v2x_obu_rsi_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.obu.ObuRsi)
  })
_sym_db.RegisterMessage(ObuRsi)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/audio/proto/audio_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/audio/proto/audio_common.proto',
  package='apollo.audio',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/audio/proto/audio_common.proto\x12\x0c\x61pollo.audio*K\n\x0cMovingResult\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0b\x41PPROACHING\x10\x01\x12\r\n\tDEPARTING\x10\x02\x12\x0e\n\nSTATIONARY\x10\x03*G\n\tAudioType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\n\n\x06POLICE\x10\x01\x12\r\n\tAMBULANCE\x10\x02\x12\r\n\tFIRETRUCK\x10\x03*Q\n\x0e\x41udioDirection\x12\x15\n\x11UNKNOWN_DIRECTION\x10\x00\x12\t\n\x05\x46RONT\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\x08\n\x04\x42\x41\x43K\x10\x03\x12\t\n\x05RIGHT\x10\x04'
)

_MOVINGRESULT = _descriptor.EnumDescriptor(
  name='MovingResult',
  full_name='apollo.audio.MovingResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPROACHING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPARTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIONARY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=56,
  serialized_end=131,
)
_sym_db.RegisterEnumDescriptor(_MOVINGRESULT)

MovingResult = enum_type_wrapper.EnumTypeWrapper(_MOVINGRESULT)
_AUDIOTYPE = _descriptor.EnumDescriptor(
  name='AudioType',
  full_name='apollo.audio.AudioType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POLICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBULANCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIRETRUCK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=133,
  serialized_end=204,
)
_sym_db.RegisterEnumDescriptor(_AUDIOTYPE)

AudioType = enum_type_wrapper.EnumTypeWrapper(_AUDIOTYPE)
_AUDIODIRECTION = _descriptor.EnumDescriptor(
  name='AudioDirection',
  full_name='apollo.audio.AudioDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_DIRECTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=206,
  serialized_end=287,
)
_sym_db.RegisterEnumDescriptor(_AUDIODIRECTION)

AudioDirection = enum_type_wrapper.EnumTypeWrapper(_AUDIODIRECTION)
UNKNOWN = 0
APPROACHING = 1
DEPARTING = 2
STATIONARY = 3
UNKNOWN_TYPE = 0
POLICE = 1
AMBULANCE = 2
FIRETRUCK = 3
UNKNOWN_DIRECTION = 0
FRONT = 1
LEFT = 2
BACK = 3
RIGHT = 4


DESCRIPTOR.enum_types_by_name['MovingResult'] = _MOVINGRESULT
DESCRIPTOR.enum_types_by_name['AudioType'] = _AUDIOTYPE
DESCRIPTOR.enum_types_by_name['AudioDirection'] = _AUDIODIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
